You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2014/12/17 17:22:49 UTC

[06/16] incubator-ignite git commit: # IGNITE-26 Created InternalFuture.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
index 012a833..ac35562 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
@@ -12,7 +12,6 @@ package org.gridgain.grid.kernal;
 import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.testframework.*;
 import org.gridgain.testframework.junits.common.*;
@@ -98,7 +97,7 @@ public class GridDeploymentMultiThreadedSelfTest extends GridCommonAbstractTest
     /**
      * Test task.
      */
-    private static class GridDeploymentTestTask extends ComputeTaskAdapter<Object, Object> {
+    private static class GridDeploymentTestTask extends ComputeTaskFutureAdapter<Object, Object> {
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
             assert false;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
index 33858b1..e9764c0 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
@@ -17,7 +17,6 @@ import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.deployment.local.*;
 import org.gridgain.testframework.junits.common.*;
 
@@ -152,7 +151,7 @@ public class GridDeploymentSelfTest extends GridCommonAbstractTest {
             ignite.compute().localDeployTask(GridDeploymentTestTask.class, GridDeploymentTestTask.class.getClassLoader());
 
             // Check auto-deploy.
-            ComputeTaskFuture<?> fut = executeAsync(ignite.compute(), GridDeploymentTestTask.class.getName(), null);
+            InternalComputeTaskFuture<?> fut = executeAsync(ignite.compute(), GridDeploymentTestTask.class.getName(), null);
 
             fut.get();
 
@@ -348,7 +347,7 @@ public class GridDeploymentSelfTest extends GridCommonAbstractTest {
     /**
      * Test deployable task.
      */
-    private static class GridDeploymentTestTask extends ComputeTaskAdapter<Object, Object> {
+    private static class GridDeploymentTestTask extends ComputeTaskFutureAdapter<Object, Object> {
         /** */
         @IgniteLoggerResource
         private IgniteLogger log;
@@ -382,7 +381,7 @@ public class GridDeploymentSelfTest extends GridCommonAbstractTest {
      * Test deployable named task.
      */
     @ComputeTaskName(value = "GridDeploymentTestTask")
-    private static class GridDeploymentTestTask1 extends ComputeTaskAdapter<Object, Object> {
+    private static class GridDeploymentTestTask1 extends ComputeTaskFutureAdapter<Object, Object> {
         /** */
         @IgniteLoggerResource
         private IgniteLogger log;
@@ -414,7 +413,7 @@ public class GridDeploymentSelfTest extends GridCommonAbstractTest {
      * Test deployable named task.
      */
     @ComputeTaskName(value = "GridDeploymentTestTask")
-    private static class GridDeploymentTestTask2 extends ComputeTaskAdapter<Object, Object> {
+    private static class GridDeploymentTestTask2 extends ComputeTaskFutureAdapter<Object, Object> {
         /** */
         @IgniteLoggerResource
         private IgniteLogger log;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
index 0c0fa14..e806c45 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
@@ -147,7 +146,7 @@ public class GridEventStorageCheckAllEventsSelfTest extends GridCommonAbstractTe
     public void testFailTask() throws Exception {
         long tstamp = startTimestamp();
 
-        ComputeTaskFuture<?> fut = generateEvents(null, new GridAllEventsFailTestJob());
+        InternalComputeTaskFuture<?> fut = generateEvents(null, new GridAllEventsFailTestJob());
 
         try {
             fut.get();
@@ -175,7 +174,7 @@ public class GridEventStorageCheckAllEventsSelfTest extends GridCommonAbstractTe
     public void testTimeoutTask() throws Exception {
         long tstamp = startTimestamp();
 
-        ComputeTaskFuture<?> fut = generateEvents(1000L, new GridAllEventsTimeoutTestJob());
+        InternalComputeTaskFuture<?> fut = generateEvents(1000L, new GridAllEventsTimeoutTestJob());
 
         try {
             fut.get();
@@ -281,7 +280,7 @@ public class GridEventStorageCheckAllEventsSelfTest extends GridCommonAbstractTe
      * @return Task future.
      * @throws Exception If failed.
      */
-    private ComputeTaskFuture<?> generateEvents(@Nullable Long timeout, ComputeJob job) throws Exception {
+    private InternalComputeTaskFuture<?> generateEvents(@Nullable Long timeout, ComputeJob job) throws Exception {
         IgniteCompute comp = ignite.compute().enableAsync();
 
         if (timeout == null)

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
index 4b5a5fa..a480072 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.testframework.*;
@@ -389,7 +388,7 @@ public class GridExplicitImplicitDeploymentSelfTest extends GridCommonAbstractTe
      */
     @SuppressWarnings({"PublicInnerClass"})
     @ComputeTaskName("GridDeploymentResourceTestTask")
-    public static class GridDeploymentResourceTestTask extends ComputeTaskAdapter<String, Integer> {
+    public static class GridDeploymentResourceTestTask extends ComputeTaskFutureAdapter<String, Integer> {
         /** */
         @IgniteLocalNodeIdResource
         private UUID locId;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
index c695b84..78722f8 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.failover.*;
 import org.apache.ignite.spi.failover.always.*;
 import org.gridgain.testframework.junits.common.*;
@@ -74,7 +73,7 @@ public class GridFailoverCustomTopologySelfTest extends GridCommonAbstractTest {
             ignite1.compute().localDeployTask(JobTask.class, JobTask.class.getClassLoader());
 
             try {
-                ComputeTaskFuture<String> fut;
+                InternalComputeTaskFuture<String> fut;
 
                 synchronized(mux){
                     IgniteCompute comp = ignite1.compute().enableAsync();
@@ -110,7 +109,7 @@ public class GridFailoverCustomTopologySelfTest extends GridCommonAbstractTest {
 
     /** */
     @SuppressWarnings("PublicInnerClass")
-    public static class JobTask extends ComputeTaskAdapter<String, String> {
+    public static class JobTask extends ComputeTaskFutureAdapter<String, String> {
         /** */
         @IgniteLoggerResource
         private IgniteLogger log;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCheckpointCleanupSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCheckpointCleanupSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCheckpointCleanupSelfTest.java
index ac2c46f..0bd3172 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCheckpointCleanupSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCheckpointCleanupSelfTest.java
@@ -6,7 +6,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.resources.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.checkpoint.*;
 import org.gridgain.testframework.junits.common.*;
 import org.jetbrains.annotations.*;
@@ -116,7 +115,7 @@ public class GridJobCheckpointCleanupSelfTest extends GridCommonAbstractTest {
      *
      */
     @ComputeTaskSessionFullSupport
-    private static class CheckpointCountingTestTask extends ComputeTaskAdapter<ClusterNode, Object> {
+    private static class CheckpointCountingTestTask extends ComputeTaskFutureAdapter<ClusterNode, Object> {
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable ClusterNode arg)
             throws IgniteCheckedException {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCollisionCancelSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCollisionCancelSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCollisionCancelSelfTest.java
index 5f646cd..08d3998 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCollisionCancelSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCollisionCancelSelfTest.java
@@ -13,7 +13,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.resources.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.collision.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;
@@ -59,7 +58,7 @@ public class GridJobCollisionCancelSelfTest extends GridCommonAbstractTest {
 
         ignite.compute().localDeployTask(GridCancelTestTask.class, GridCancelTestTask.class.getClassLoader());
 
-        ComputeTaskFuture<?> res0 =
+        InternalComputeTaskFuture<?> res0 =
             executeAsync(ignite.compute().withTimeout(maxJobExecTime * 2), GridCancelTestTask.class.getName(), null);
 
         try {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobStealingSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobStealingSelfTest.java
index 60b3458..a063700 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobStealingSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobStealingSelfTest.java
@@ -16,7 +16,6 @@ import org.apache.ignite.configuration.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.marshaller.optimized.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.collision.jobstealing.*;
 import org.apache.ignite.spi.failover.jobstealing.*;
 import org.gridgain.grid.util.typedef.*;
@@ -291,7 +290,7 @@ public class GridJobStealingSelfTest extends GridCommonAbstractTest {
     /**
      * Job stealing task, that spreads jobs equally over the grid.
      */
-    private static class JobStealingSpreadTask extends ComputeTaskAdapter<Object, Object> {
+    private static class JobStealingSpreadTask extends ComputeTaskFutureAdapter<Object, Object> {
         /** Grid. */
         @IgniteInstanceResource
         private Ignite ignite;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobStealingZeroActiveJobsSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobStealingZeroActiveJobsSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobStealingZeroActiveJobsSelfTest.java
index 8641fc9..742b1d3 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobStealingZeroActiveJobsSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobStealingZeroActiveJobsSelfTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.collision.jobstealing.*;
 import org.apache.ignite.spi.failover.jobstealing.*;
 import org.gridgain.testframework.junits.common.*;
@@ -85,7 +84,7 @@ public class GridJobStealingZeroActiveJobsSelfTest extends GridCommonAbstractTes
 
     /** */
     @SuppressWarnings({"PublicInnerClass"})
-    public static class JobStealingTask extends ComputeTaskAdapter<Object, Object> {
+    public static class JobStealingTask extends ComputeTaskFutureAdapter<Object, Object> {
         /** Grid. */
         @IgniteInstanceResource
         private Ignite ignite;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobSubjectIdSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobSubjectIdSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobSubjectIdSelfTest.java
index 7d3bc4e..f2f25d1 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobSubjectIdSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobSubjectIdSelfTest.java
@@ -15,7 +15,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;
 import org.jetbrains.annotations.*;
@@ -83,7 +82,7 @@ public class GridJobSubjectIdSelfTest extends GridCommonAbstractTest {
      * Task class.
      */
     @SuppressWarnings("PublicInnerClass")
-    public static class Task extends ComputeTaskAdapter<Object, Object> {
+    public static class Task extends ComputeTaskFutureAdapter<Object, Object> {
         /** Target node ID. */
         private UUID targetNodeId;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleJobsSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleJobsSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleJobsSelfTest.java
index 186c9e5..78e9495 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleJobsSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleJobsSelfTest.java
@@ -12,7 +12,6 @@ package org.gridgain.grid.kernal;
 import org.apache.ignite.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.cache.affinity.*;
 import org.apache.ignite.spi.discovery.tcp.*;
@@ -145,13 +144,13 @@ public class GridMultipleJobsSelfTest extends GridCommonAbstractTest {
 
                     comp.call(job);
 
-                    IgniteFuture<Boolean> fut = comp.future();
+                    InternalFuture<Boolean> fut = comp.future();
 
                     if (cnt % LOG_MOD == 0)
                         X.println("Submitted jobs: " + cnt);
 
-                    fut.listenAsync(new CIX1<IgniteFuture<Boolean>>() {
-                        @Override public void applyx(IgniteFuture<Boolean> f) throws IgniteCheckedException {
+                    fut.listenAsync(new CIX1<InternalFuture<Boolean>>() {
+                        @Override public void applyx(InternalFuture<Boolean> f) throws IgniteCheckedException {
                             try {
                                 assert f.get();
                             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleSpisSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleSpisSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleSpisSelfTest.java
index c7fde8e..427df32 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleSpisSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleSpisSelfTest.java
@@ -15,7 +15,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.resources.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.checkpoint.sharedfs.*;
 import org.apache.ignite.spi.failover.*;
 import org.apache.ignite.spi.failover.always.*;
@@ -220,7 +219,7 @@ public class GridMultipleSpisSelfTest extends GridCommonAbstractTest {
     @SuppressWarnings({"PublicInnerClass"})
     @ComputeTaskSpis(loadBalancingSpi = "load2", failoverSpi = "fail2", checkpointSpi = "cp2")
     @ComputeTaskSessionFullSupport
-    public static final class GridTestMultipleSpisTask extends ComputeTaskAdapter<UUID, Integer> {
+    public static final class GridTestMultipleSpisTask extends ComputeTaskFutureAdapter<UUID, Integer> {
         /** */
         @IgniteTaskSessionResource
         private ComputeTaskSession taskSes;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleVersionsDeploymentSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleVersionsDeploymentSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleVersionsDeploymentSelfTest.java
index 3753614..bfa0644 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleVersionsDeploymentSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultipleVersionsDeploymentSelfTest.java
@@ -16,7 +16,6 @@ import org.apache.ignite.configuration.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.testframework.*;
 import org.gridgain.testframework.junits.common.*;
 
@@ -104,7 +103,7 @@ public class GridMultipleVersionsDeploymentSelfTest extends GridCommonAbstractTe
             ignite.compute().localDeployTask(taskCls1, ldr1);
 
             // Task will wait for the signal.
-            ComputeTaskFuture fut = executeAsync(ignite.compute(), "GridDeploymentTestTask", null);
+            InternalComputeTaskFuture fut = executeAsync(ignite.compute(), "GridDeploymentTestTask", null);
 
             // We should wait here when to be sure that job has been started.
             // Since we loader task/job classes with different class loaders we cannot
@@ -177,7 +176,7 @@ public class GridMultipleVersionsDeploymentSelfTest extends GridCommonAbstractTe
             g1.compute().localDeployTask(taskCls1, ldr1);
 
             // Task will wait for the signal.
-            ComputeTaskFuture fut1 = executeAsync(g1.compute(), "GridDeploymentTestTask", null);
+            InternalComputeTaskFuture fut1 = executeAsync(g1.compute(), "GridDeploymentTestTask", null);
 
             assert checkDeployed(g1, "GridDeploymentTestTask");
 
@@ -191,7 +190,7 @@ public class GridMultipleVersionsDeploymentSelfTest extends GridCommonAbstractTe
             g1.compute().localDeployTask(taskCls2, ldr2);
 
             // Task will wait for the signal.
-            ComputeTaskFuture fut2 = executeAsync(g1.compute(), "GridDeploymentTestTask", null);
+            InternalComputeTaskFuture fut2 = executeAsync(g1.compute(), "GridDeploymentTestTask", null);
 
             boolean deployed = checkDeployed(g1, "GridDeploymentTestTask");
 
@@ -225,7 +224,7 @@ public class GridMultipleVersionsDeploymentSelfTest extends GridCommonAbstractTe
      */
     @SuppressWarnings({"PublicInnerClass"})
     @ComputeTaskName(value="GridDeploymentTestTask")
-    public static class GridDeploymentTestTask extends ComputeTaskAdapter<Object, Object> {
+    public static class GridDeploymentTestTask extends ComputeTaskFutureAdapter<Object, Object> {
         /** */
         @IgniteLocalNodeIdResource
         private UUID locNodeId;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultithreadedJobStealingSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultithreadedJobStealingSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultithreadedJobStealingSelfTest.java
index 6335dda..19bef0d 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultithreadedJobStealingSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridMultithreadedJobStealingSelfTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.collision.jobstealing.*;
 import org.apache.ignite.spi.failover.jobstealing.*;
 import org.gridgain.grid.util.typedef.*;
@@ -140,7 +139,7 @@ public class GridMultithreadedJobStealingSelfTest extends GridCommonAbstractTest
     /**
      * Job stealing task.
      */
-    private static class JobStealingTask extends ComputeTaskAdapter<Object, JobStealingResult> {
+    private static class JobStealingTask extends ComputeTaskFutureAdapter<Object, JobStealingResult> {
         /** Grid. */
         @IgniteInstanceResource
         private Ignite ignite;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridProjectionAbstractTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridProjectionAbstractTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridProjectionAbstractTest.java
index d375fd8..560b609 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridProjectionAbstractTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridProjectionAbstractTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;
 import org.jetbrains.annotations.*;
@@ -320,7 +319,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.broadcast(runJob);
 
-        IgniteFuture fut = comp.future();
+        InternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -342,7 +341,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.run(jobs);
 
-        IgniteFuture fut = comp.future();
+        InternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -362,7 +361,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.broadcast(calJob);
 
-        IgniteFuture fut = comp.future();
+        InternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -384,7 +383,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.call(jobs);
 
-        IgniteFuture fut = comp.future();
+        InternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -404,7 +403,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.apply(clrJob, (String) null);
 
-        IgniteFuture fut = comp.future();
+        InternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -426,7 +425,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.apply(clrJob, args);
 
-        IgniteFuture fut = comp.future();
+        InternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -446,7 +445,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.broadcast(new TestClosure(), "arg");
 
-        IgniteFuture<Collection<String>> fut = comp.future();
+        InternalFuture<Collection<String>> fut = comp.future();
 
         waitForExecution(fut);
 
@@ -473,7 +472,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.apply(clrJob, args, rdc);
 
-        IgniteFuture fut = comp.future();
+        InternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -495,7 +494,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.call(jobs, rdc);
 
-        IgniteFuture fut = comp.future();
+        InternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -595,7 +594,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
      * @throws InterruptedException Thrown if wait was interrupted.
      */
     @SuppressWarnings({"UnconditionalWait"})
-    private void waitForExecution(IgniteFuture fut) throws InterruptedException {
+    private void waitForExecution(InternalFuture fut) throws InterruptedException {
         long sleep = 250;
 
         long threshold = System.currentTimeMillis() + WAIT_TIMEOUT;
@@ -642,16 +641,16 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         cnt.set(0);
 
-        Collection<ComputeTaskFuture<Object>> futsList = new ArrayList<>();
+        Collection<InternalComputeTaskFuture<Object>> futsList = new ArrayList<>();
 
         for (int i = 0; i < 10; i++) {
             comp.call(new TestWaitCallable<Object>());
 
-            ComputeTaskFuture<Object> fut = comp.future();
+            InternalComputeTaskFuture<Object> fut = comp.future();
 
             assertFalse(fut.isDone());
 
-            Map<IgniteUuid, ComputeTaskFuture<Object>> futs = comp.activeTaskFutures();
+            Map<IgniteUuid, InternalComputeTaskFuture<Object>> futs = comp.activeTaskFutures();
 
             assertEquals(i + 1, futs.size());
 
@@ -666,7 +665,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
             mux.notifyAll();
         }
 
-        for (ComputeTaskFuture<Object> fut : futsList)
+        for (InternalComputeTaskFuture<Object> fut : futsList)
             fut.get();
 
         assertEquals(0, comp.activeTaskFutures().size());

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridReduceSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridReduceSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridReduceSelfTest.java
index 3f24b06..f46a858 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridReduceSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridReduceSelfTest.java
@@ -100,7 +100,7 @@ public class GridReduceSelfTest extends GridCommonAbstractTest {
                 }
             });
 
-            IgniteFuture<Long> fut = comp.future();
+            InternalFuture<Long> fut = comp.future();
 
             assertEquals((Long)1L, fut.get());
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridRuntimeExceptionSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridRuntimeExceptionSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridRuntimeExceptionSelfTest.java
index 967ffd3..f4522ae 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridRuntimeExceptionSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridRuntimeExceptionSelfTest.java
@@ -15,7 +15,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;
 
@@ -68,7 +67,7 @@ public class GridRuntimeExceptionSelfTest extends GridCommonAbstractTest {
 
         ignite.compute().localDeployTask(GridTaskFailedTestTask.class, GridTaskFailedTestTask.class.getClassLoader());
 
-        ComputeTaskFuture<?> fut =
+        InternalComputeTaskFuture<?> fut =
             executeAsync(ignite.compute(), GridTaskFailedTestTask.class.getName(), FailType.EXECUTE);
 
         try {
@@ -98,7 +97,7 @@ public class GridRuntimeExceptionSelfTest extends GridCommonAbstractTest {
 
         ignite.compute().localDeployTask(GridTaskFailedTestTask.class, GridTaskFailedTestTask.class.getClassLoader());
 
-        ComputeTaskFuture<?> fut =
+        InternalComputeTaskFuture<?> fut =
             executeAsync(ignite.compute(), GridTaskFailedTestTask.class.getName(), FailType.MAP);
 
         try {
@@ -128,7 +127,7 @@ public class GridRuntimeExceptionSelfTest extends GridCommonAbstractTest {
 
         ignite.compute().localDeployTask(GridTaskFailedTestTask.class, GridTaskFailedTestTask.class.getClassLoader());
 
-        ComputeTaskFuture<?> fut =
+        InternalComputeTaskFuture<?> fut =
             executeAsync(ignite.compute(), GridTaskFailedTestTask.class.getName(), FailType.RESULT);
 
         try {
@@ -158,7 +157,7 @@ public class GridRuntimeExceptionSelfTest extends GridCommonAbstractTest {
 
         ignite.compute().localDeployTask(GridTaskFailedTestTask.class, GridTaskFailedTestTask.class.getClassLoader());
 
-        ComputeTaskFuture<?> fut =
+        InternalComputeTaskFuture<?> fut =
             executeAsync(ignite.compute(), GridTaskFailedTestTask.class.getName(), FailType.RESULT);
 
         try {
@@ -202,7 +201,7 @@ public class GridRuntimeExceptionSelfTest extends GridCommonAbstractTest {
     }
 
     /** */
-    private static class GridTaskFailedTestTask extends ComputeTaskAdapter<Serializable, Serializable> {
+    private static class GridTaskFailedTestTask extends ComputeTaskFutureAdapter<Serializable, Serializable> {
         /** */
         @IgniteLoggerResource
         private IgniteLogger log;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridStopWithCancelSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridStopWithCancelSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridStopWithCancelSelfTest.java
index 89f6ee2..31bd77e 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridStopWithCancelSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridStopWithCancelSelfTest.java
@@ -13,7 +13,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.testframework.junits.common.*;
 import org.jetbrains.annotations.*;
 
@@ -70,7 +69,7 @@ public class GridStopWithCancelSelfTest extends GridCommonAbstractTest {
      * Test task that will be canceled.
      */
     @SuppressWarnings({"PublicInnerClass"})
-    public static final class CancelledTask extends ComputeTaskAdapter<String, Object> {
+    public static final class CancelledTask extends ComputeTaskFutureAdapter<String, Object> {
         /** */
         @IgniteLocalNodeIdResource
         private UUID locId;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridStopWithWaitSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridStopWithWaitSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridStopWithWaitSelfTest.java
index c7b0f2a..a773373 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridStopWithWaitSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridStopWithWaitSelfTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.failover.always.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;
@@ -57,7 +56,7 @@ public class GridStopWithWaitSelfTest extends GridCommonAbstractTest {
     public void testWait() throws Exception {
         jobStarted = new CountDownLatch(1);
 
-        ComputeTaskFuture<Object> fut = null;
+        InternalComputeTaskFuture<Object> fut = null;
 
         try {
             Ignite ignite1 = startGrid(1);
@@ -91,7 +90,7 @@ public class GridStopWithWaitSelfTest extends GridCommonAbstractTest {
     public void testWaitFailover() throws Exception {
         jobStarted = new CountDownLatch(1);
 
-        ComputeTaskFuture<Object> fut = null;
+        InternalComputeTaskFuture<Object> fut = null;
 
         Ignite ignite1 = startGrid(1);
         Ignite ignite2 = startGrid(2);
@@ -123,7 +122,7 @@ public class GridStopWithWaitSelfTest extends GridCommonAbstractTest {
      *
      */
     @ComputeTaskSessionFullSupport
-    private static class GridWaitTask extends ComputeTaskAdapter<UUID, Integer> {
+    private static class GridWaitTask extends ComputeTaskFutureAdapter<UUID, Integer> {
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, UUID arg) throws IgniteCheckedException {
             ClusterNode mappedNode = null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskCancelSingleNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskCancelSingleNodeSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskCancelSingleNodeSelfTest.java
index 604dd62..afaf942 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskCancelSingleNodeSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskCancelSingleNodeSelfTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.testframework.junits.common.*;
@@ -97,7 +96,7 @@ public class GridTaskCancelSingleNodeSelfTest extends GridCommonAbstractTest {
 
         comp.execute(TestTask.class, null);
 
-        ComputeTaskFuture<?> fut = comp.future();
+        InternalComputeTaskFuture<?> fut = comp.future();
 
         if (timeoutBeforeCancel > 0L)
             Thread.sleep(timeoutBeforeCancel);
@@ -131,7 +130,7 @@ public class GridTaskCancelSingleNodeSelfTest extends GridCommonAbstractTest {
 
             assert false;
         }
-        catch (IgniteFutureCancelledException e) {
+        catch (InternalFutureCancelledException e) {
             info("Caught expected exception: " + e);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskContinuousMapperSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskContinuousMapperSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskContinuousMapperSelfTest.java
index 526e74d..6a13bc4 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskContinuousMapperSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskContinuousMapperSelfTest.java
@@ -13,7 +13,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.testframework.junits.common.*;
 
 import java.io.*;
@@ -70,7 +69,7 @@ public class GridTaskContinuousMapperSelfTest extends GridCommonAbstractTest {
 
     /** */
     @SuppressWarnings({"PublicInnerClass"})
-    public static class TestAllMethodsTask extends ComputeTaskAdapter<Object, Object> {
+    public static class TestAllMethodsTask extends ComputeTaskFutureAdapter<Object, Object> {
         /** */
         @SuppressWarnings({"UnusedDeclaration"})
         @IgniteTaskContinuousMapperResource
@@ -116,7 +115,7 @@ public class GridTaskContinuousMapperSelfTest extends GridCommonAbstractTest {
 
     /** */
     @SuppressWarnings({"PublicInnerClass"})
-    public static class TestLifeCycleTask extends ComputeTaskAdapter<Object, Object> {
+    public static class TestLifeCycleTask extends ComputeTaskFutureAdapter<Object, Object> {
         /** */
         @IgniteLoggerResource
         private IgniteLogger log;
@@ -205,7 +204,7 @@ public class GridTaskContinuousMapperSelfTest extends GridCommonAbstractTest {
 
     /** */
     @SuppressWarnings({"PublicInnerClass"})
-    public static class TestNegativeTask extends ComputeTaskAdapter<Object, Object> {
+    public static class TestNegativeTask extends ComputeTaskFutureAdapter<Object, Object> {
         /** */
         @SuppressWarnings({"UnusedDeclaration"})
         @IgniteTaskContinuousMapperResource

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskExecutionSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskExecutionSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskExecutionSelfTest.java
index 6065786..12155d3 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskExecutionSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskExecutionSelfTest.java
@@ -52,7 +52,7 @@ public class GridTaskExecutionSelfTest extends GridCommonAbstractTest {
 
         assertNull(comp.execute(GridTestTask.class,  "testArg"));
 
-        ComputeTaskFuture<?> fut = comp.future();
+        InternalComputeTaskFuture<?> fut = comp.future();
 
         assert fut != null;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskFailoverSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskFailoverSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskFailoverSelfTest.java
index 247c249..70f1dc6 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskFailoverSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskFailoverSelfTest.java
@@ -12,7 +12,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.testframework.junits.common.*;
 
 import java.io.*;
@@ -41,7 +40,7 @@ public class GridTaskFailoverSelfTest extends GridCommonAbstractTest {
         try {
             ignite.compute().localDeployTask(GridFailoverTestTask.class, GridFailoverTestTask.class.getClassLoader());
 
-            ComputeTaskFuture<?> fut = ignite.compute().execute(GridFailoverTestTask.class.getName(), null);
+            InternalComputeTaskFuture<?> fut = ignite.compute().execute(GridFailoverTestTask.class.getName(), null);
 
             assert fut != null;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskFutureImplStopGridSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskFutureImplStopGridSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskFutureImplStopGridSelfTest.java
index 955d696..cce13b6 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskFutureImplStopGridSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskFutureImplStopGridSelfTest.java
@@ -13,7 +13,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;
 
@@ -58,11 +57,11 @@ public class GridTaskFutureImplStopGridSelfTest extends GridCommonAbstractTest {
         Thread futThread = null;
 
         try {
-            final ComputeTaskFuture<?> fut = executeAsync(ignite.compute(), GridStopTestTask.class.getName(), null);
+            final InternalComputeTaskFuture<?> fut = executeAsync(ignite.compute(), GridStopTestTask.class.getName(), null);
 
-            fut.listenAsync(new CI1<IgniteFuture>() {
+            fut.listenAsync(new CI1<InternalFuture>() {
                 @SuppressWarnings({"NakedNotify"})
-                @Override public void apply(IgniteFuture gridFut) {
+                @Override public void apply(InternalFuture gridFut) {
                     synchronized (mux) {
                         mux.notifyAll();
                     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskInstanceExecutionSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskInstanceExecutionSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskInstanceExecutionSelfTest.java
index cd63264..05e1db1 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskInstanceExecutionSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskInstanceExecutionSelfTest.java
@@ -49,7 +49,7 @@ public class GridTaskInstanceExecutionSelfTest extends GridCommonAbstractTest {
 
         assertNull(comp.execute(task,  "testArg"));
 
-        ComputeTaskFuture<?> fut = comp.future();
+        InternalComputeTaskFuture<?> fut = comp.future();
 
         assert fut != null;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskInstantiationSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskInstantiationSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskInstantiationSelfTest.java
index 2ce5c70..f6dd0a3 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskInstantiationSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskInstantiationSelfTest.java
@@ -53,7 +53,7 @@ public class GridTaskInstantiationSelfTest extends GridCommonAbstractTest {
     /**
      * Test task defined as private inner class.
      */
-    private static class PrivateClassTask extends ComputeTaskAdapter<String, Object> {
+    private static class PrivateClassTask extends ComputeTaskFutureAdapter<String, Object> {
         /** */
         @IgniteLocalNodeIdResource
         private UUID locId;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskJobRejectSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskJobRejectSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskJobRejectSelfTest.java
index 5e3edcf..1ddf4dc 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskJobRejectSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskJobRejectSelfTest.java
@@ -15,7 +15,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.collision.fifoqueue.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;
@@ -111,7 +110,7 @@ public class GridTaskJobRejectSelfTest extends GridCommonAbstractTest {
 
         IgniteCompute comp = grid(1).compute().enableAsync();
 
-        comp.execute(new ComputeTaskAdapter<Void, Void>() {
+        comp.execute(new ComputeTaskFutureAdapter<Void, Void>() {
             @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid,
                 @Nullable Void arg) {
                 return F.asMap(new SleepJob(), node, new SleepJob(), node);
@@ -123,7 +122,7 @@ public class GridTaskJobRejectSelfTest extends GridCommonAbstractTest {
             }
         }, null);
 
-        ComputeTaskFuture<?> fut = comp.future();
+        InternalComputeTaskFuture<?> fut = comp.future();
 
         assert startedLatch.await(2, SECONDS);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskListenerSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskListenerSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskListenerSelfTest.java
index 680cfd5..e93fd62 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskListenerSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskListenerSelfTest.java
@@ -12,7 +12,6 @@ package org.gridgain.grid.kernal;
 import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;
 
@@ -40,8 +39,8 @@ public class GridTaskListenerSelfTest extends GridCommonAbstractTest {
     public void testGridTaskListener() throws Exception {
         final AtomicInteger cnt = new AtomicInteger(0);
 
-        IgniteInClosure<IgniteFuture<?>> lsnr = new CI1<IgniteFuture<?>>() {
-            @Override public void apply(IgniteFuture<?> fut) {
+        IgniteInClosure<InternalFuture<?>> lsnr = new CI1<InternalFuture<?>>() {
+            @Override public void apply(InternalFuture<?> fut) {
                 assert fut != null;
 
                 cnt.incrementAndGet();
@@ -54,7 +53,7 @@ public class GridTaskListenerSelfTest extends GridCommonAbstractTest {
 
         ignite.compute().localDeployTask(TestTask.class, TestTask.class.getClassLoader());
 
-        ComputeTaskFuture<?> fut = executeAsync(ignite.compute(), TestTask.class.getName(), null);
+        InternalComputeTaskFuture<?> fut = executeAsync(ignite.compute(), TestTask.class.getName(), null);
 
         fut.listenAsync(lsnr);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskTimeoutSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskTimeoutSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskTimeoutSelfTest.java
index 67c4d32..9cde576 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskTimeoutSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridTaskTimeoutSelfTest.java
@@ -13,7 +13,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;
 
@@ -69,7 +68,7 @@ public class GridTaskTimeoutSelfTest extends GridCommonAbstractTest {
 
         ignite.compute().localDeployTask(GridTaskTimeoutTestTask.class, GridTaskTimeoutTestTask.class.getClassLoader());
 
-        ComputeTaskFuture<?> fut = executeAsync(ignite.compute().withTimeout(TIMEOUT),
+        InternalComputeTaskFuture<?> fut = executeAsync(ignite.compute().withTimeout(TIMEOUT),
             GridTaskTimeoutTestTask.class.getName(), null);
 
         try {
@@ -94,7 +93,7 @@ public class GridTaskTimeoutSelfTest extends GridCommonAbstractTest {
 
         ignite.compute().localDeployTask(GridTaskTimeoutTestTask.class, GridTaskTimeoutTestTask.class.getClassLoader());
 
-        ComputeTaskFuture<?> fut = executeAsync(ignite.compute().withTimeout(TIMEOUT),
+        InternalComputeTaskFuture<?> fut = executeAsync(ignite.compute().withTimeout(TIMEOUT),
             GridTaskTimeoutTestTask.class.getName(), null);
 
         // Allow timed out events to be executed.
@@ -135,7 +134,7 @@ public class GridTaskTimeoutSelfTest extends GridCommonAbstractTest {
             @Override public void run() {
                 while (!finish.get()) {
                     try {
-                        ComputeTaskFuture<?> fut = executeAsync(
+                        InternalComputeTaskFuture<?> fut = executeAsync(
                             ignite.compute().withTimeout(TIMEOUT), GridTaskTimeoutTestTask.class.getName(), null);
 
                         fut.get();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/managers/checkpoint/GridCheckpointManagerAbstractSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/managers/deployment/GridDeploymentMessageCountSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/managers/deployment/GridDeploymentMessageCountSelfTest.java
index e16e19b..17b4609 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/managers/deployment/GridDeploymentMessageCountSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/managers/deployment/GridDeploymentMessageCountSelfTest.java
@@ -83,7 +83,7 @@ public class GridDeploymentMessageCountSelfTest extends GridCommonAbstractTest {
         try {
             startGrids(2);
 
-            ComputeTaskFuture<Object> taskFut = executeAsync(grid(0).compute(), taskCls, 2);
+            InternalComputeTaskFuture<Object> taskFut = executeAsync(grid(0).compute(), taskCls, 2);
 
             Integer res = (Integer)taskFut.get();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/managers/events/GridEventStorageManagerSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/managers/events/GridEventStorageManagerSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/managers/events/GridEventStorageManagerSelfTest.java
index 0614969..369fc1c 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/managers/events/GridEventStorageManagerSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/managers/events/GridEventStorageManagerSelfTest.java
@@ -53,7 +53,7 @@ public class GridEventStorageManagerSelfTest extends GridCommonAbstractTest {
 
         final int usrType = Integer.MAX_VALUE - 1;
 
-        IgniteFuture<IgniteEvent> fut = waitForLocalEvent(ignite.events(), new IgnitePredicate<IgniteEvent>() {
+        InternalFuture<IgniteEvent> fut = waitForLocalEvent(ignite.events(), new IgnitePredicate<IgniteEvent>() {
             @Override public boolean apply(IgniteEvent e) {
                 return e.type() == usrType;
             }
@@ -64,7 +64,7 @@ public class GridEventStorageManagerSelfTest extends GridCommonAbstractTest {
 
             fail("GridFutureTimeoutException must have been thrown.");
         }
-        catch (IgniteFutureTimeoutException e) {
+        catch (InternalFutureTimeoutException e) {
             info("Caught expected exception: " + e);
         }
 
@@ -91,7 +91,7 @@ public class GridEventStorageManagerSelfTest extends GridCommonAbstractTest {
 
             fail("GridFutureTimeoutException must have been thrown.");
         }
-        catch (IgniteFutureTimeoutException e) {
+        catch (InternalFutureTimeoutException e) {
             info("Caught expected exception: " + e);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFailoverSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFailoverSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFailoverSelfTest.java
index aa0b031..1aa6b54 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFailoverSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFailoverSelfTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.cluster.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
@@ -247,7 +246,7 @@ public abstract class GridCacheAbstractFailoverSelfTest extends GridCacheAbstrac
 
         final int half = ENTRY_CNT / 2;
 
-        IgniteFuture<?> fut = GridTestUtils.runMultiThreadedAsync(new CA() {
+        InternalFuture<?> fut = GridTestUtils.runMultiThreadedAsync(new CA() {
             @Override public void apply() {
                 info("Run topology change.");
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFlagsTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFlagsTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFlagsTest.java
index 340c24f..decc0ff 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFlagsTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFlagsTest.java
@@ -57,7 +57,7 @@ public abstract class GridCacheAbstractFlagsTest extends GridCacheAbstractSelfTe
 
             final AtomicInteger cntr = new AtomicInteger();
 
-            IgniteFuture<?> f = multithreadedAsync(new Callable() {
+            InternalFuture<?> f = multithreadedAsync(new Callable() {
                 @Override public Object call() throws Exception {
                     int idx = cntr.getAndIncrement() % gridCount();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFullApiMultithreadedSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFullApiMultithreadedSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFullApiMultithreadedSelfTest.java
index b24b3b2..ef02f15 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFullApiMultithreadedSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFullApiMultithreadedSelfTest.java
@@ -64,7 +64,7 @@ public abstract class GridCacheAbstractFullApiMultithreadedSelfTest extends Grid
      * @throws Exception In case of error.
      */
     private void runTest(final IgniteInClosure<GridCache<String, Integer>> c) throws Exception {
-        final IgniteFuture<?> fut1 = GridTestUtils.runMultiThreadedAsync(new CAX() {
+        final InternalFuture<?> fut1 = GridTestUtils.runMultiThreadedAsync(new CAX() {
             @Override public void applyx() throws IgniteCheckedException {
                 while (true) {
                     int i = cnt.getAndIncrement();
@@ -82,7 +82,7 @@ public abstract class GridCacheAbstractFullApiMultithreadedSelfTest extends Grid
             }
         }, WRITE_THREAD_CNT, WRITE_THREAD_NAME);
 
-        IgniteFuture<?> fut2 = GridTestUtils.runMultiThreadedAsync(new CA() {
+        InternalFuture<?> fut2 = GridTestUtils.runMultiThreadedAsync(new CA() {
             @Override public void apply() {
                 GridCache<String, Integer> cache = cache();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFullApiSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFullApiSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFullApiSelfTest.java
index 7ac3801..fdba86c 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFullApiSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheAbstractFullApiSelfTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.cluster.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.apache.ignite.spi.swapspace.inmemory.*;
 import org.gridgain.grid.util.lang.*;
@@ -401,9 +400,9 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
         cache().put("key1", 1);
         cache().put("key2", 2);
 
-        IgniteFuture<Integer> fut1 = cache().getAsync("key1");
-        IgniteFuture<Integer> fut2 = cache().getAsync("key2");
-        IgniteFuture<Integer> fut3 = cache().getAsync("wrongKey");
+        InternalFuture<Integer> fut1 = cache().getAsync("key1");
+        InternalFuture<Integer> fut2 = cache().getAsync("key2");
+        InternalFuture<Integer> fut3 = cache().getAsync("wrongKey");
 
         assert fut1.get() == 1;
         assert fut2.get() == 2;
@@ -417,8 +416,8 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
         cache().put("key1", 1);
         cache().put("key2", 100);
 
-        IgniteFuture<Integer> fut1 = cache().projection(gte100).getAsync("key1");
-        IgniteFuture<Integer> fut2 = cache().projection(gte100).getAsync("key2");
+        InternalFuture<Integer> fut1 = cache().projection(gte100).getAsync("key1");
+        InternalFuture<Integer> fut2 = cache().projection(gte100).getAsync("key2");
 
         assert fut1.get() == null;
         assert fut2.get() == 100;
@@ -623,9 +622,9 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
         cache().put("key1", 1);
         cache().put("key2", 2);
 
-        IgniteFuture<Map<String, Integer>> fut1 = cache().getAllAsync(null);
-        IgniteFuture<Map<String, Integer>> fut2 = cache().getAllAsync(Collections.<String>emptyList());
-        IgniteFuture<Map<String, Integer>> fut3 = cache().getAllAsync(F.asList("key1", "key2"));
+        InternalFuture<Map<String, Integer>> fut1 = cache().getAllAsync(null);
+        InternalFuture<Map<String, Integer>> fut2 = cache().getAllAsync(Collections.<String>emptyList());
+        InternalFuture<Map<String, Integer>> fut3 = cache().getAllAsync(F.asList("key1", "key2"));
 
         assert fut1.get().isEmpty();
         assert fut2.get().isEmpty();
@@ -645,8 +644,8 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
 
         List<String> keys = F.asList("key1", "key2", "key3", "key4");
 
-        IgniteFuture<Map<String, Integer>> fut1 = cache().projection(gte100).getAllAsync(keys);
-        IgniteFuture<Map<String, Integer>> fut2 = cache().projection(gte200).getAllAsync(keys);
+        InternalFuture<Map<String, Integer>> fut1 = cache().projection(gte100).getAllAsync(keys);
+        InternalFuture<Map<String, Integer>> fut2 = cache().projection(gte200).getAllAsync(keys);
 
         assert fut1.get().size() == 4 : "Invalid map: " + fut1.get();
         assert fut1.get().get("key1") == 100;
@@ -1153,8 +1152,8 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
         cache().put("key1", 1);
         cache().put("key2", 2);
 
-        IgniteFuture<Integer> fut1 = cache().putAsync("key1", 10);
-        IgniteFuture<Integer> fut2 = cache().putAsync("key2", 11);
+        InternalFuture<Integer> fut1 = cache().putAsync("key1", 10);
+        InternalFuture<Integer> fut2 = cache().putAsync("key2", 11);
 
         assertEquals((Integer)1, fut1.get(5000));
         assertEquals((Integer)2, fut2.get(5000));
@@ -1167,8 +1166,8 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
      * @throws Exception In case of error.
      */
     public void testPutAsync0() throws Exception {
-        IgniteFuture<Integer> fut1 = cache().putAsync("key1", 0);
-        IgniteFuture<Integer> fut2 = cache().putAsync("key2", 1);
+        InternalFuture<Integer> fut1 = cache().putAsync("key1", 0);
+        InternalFuture<Integer> fut2 = cache().putAsync("key2", 1);
 
         assert fut1.get(5000) == null;
         assert fut2.get(5000) == null;
@@ -1201,9 +1200,9 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
         cache.put("key2", 1);
         cache.put("key3", 3);
 
-        IgniteFuture<?> fut0 = cache.transformAsync("key1", INCR_CLOS);
-        IgniteFuture<?> fut1 = cache.transformAsync("key2", INCR_CLOS);
-        IgniteFuture<?> fut2 = cache.transformAsync("key3", RMV_CLOS);
+        InternalFuture<?> fut0 = cache.transformAsync("key1", INCR_CLOS);
+        InternalFuture<?> fut1 = cache.transformAsync("key2", INCR_CLOS);
+        InternalFuture<?> fut2 = cache.transformAsync("key3", RMV_CLOS);
 
         fut0.get();
         fut1.get();
@@ -1551,10 +1550,10 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
 
         cache().put("key2", 1);
 
-        IgniteFuture<Boolean> fut1 = cache().putxAsync("key1", 10);
-        IgniteFuture<Boolean> fut2 = cache().putxAsync("key2", 11);
+        InternalFuture<Boolean> fut1 = cache().putxAsync("key1", 10);
+        InternalFuture<Boolean> fut2 = cache().putxAsync("key2", 11);
 
-        IgniteFuture<GridCacheTx> f = tx == null ? null : tx.commitAsync();
+        InternalFuture<GridCacheTx> f = tx == null ? null : tx.commitAsync();
 
         assert fut1.get();
         assert fut2.get();
@@ -1571,12 +1570,12 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
      * @throws Exception In case of error.
      */
     public void testPutxAsyncFiltered() throws Exception {
-        IgniteFuture<Boolean> f1 = cache().putxAsync("key1", 1);
-        IgniteFuture<Boolean> f2 = cache().putxAsync("key1", 101, F.<String, Integer>cacheHasPeekValue());
-        IgniteFuture<Boolean> f3 = cache().putxAsync("key2", 2);
-        IgniteFuture<Boolean> f4 = cache().putxAsync("key2", 202, F.<String, Integer>cacheHasPeekValue());
-        IgniteFuture<Boolean> f5 = cache().putxAsync("key1", 1, F.<String, Integer>cacheNoPeekValue());
-        IgniteFuture<Boolean> f6 = cache().putxAsync("key2", 2, F.<String, Integer>cacheNoPeekValue());
+        InternalFuture<Boolean> f1 = cache().putxAsync("key1", 1);
+        InternalFuture<Boolean> f2 = cache().putxAsync("key1", 101, F.<String, Integer>cacheHasPeekValue());
+        InternalFuture<Boolean> f3 = cache().putxAsync("key2", 2);
+        InternalFuture<Boolean> f4 = cache().putxAsync("key2", 202, F.<String, Integer>cacheHasPeekValue());
+        InternalFuture<Boolean> f5 = cache().putxAsync("key1", 1, F.<String, Integer>cacheNoPeekValue());
+        InternalFuture<Boolean> f6 = cache().putxAsync("key2", 2, F.<String, Integer>cacheNoPeekValue());
 
         assert f1.get() : "Invalid future1: " + f1;
         assert f2.get() : "Invalid future2: " + f2;
@@ -1689,12 +1688,12 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
     public void testPutAllAsync() throws Exception {
         Map<String, Integer> map = F.asMap("key1", 1, "key2", 2);
 
-        IgniteFuture<?> f1 = cache().putAllAsync(map);
+        InternalFuture<?> f1 = cache().putAllAsync(map);
 
         map.put("key1", 10);
         map.put("key2", 20);
 
-        IgniteFuture<?> f2 = cache().putAllAsync(map);
+        InternalFuture<?> f2 = cache().putAllAsync(map);
 
         f2.get();
         f1.get();
@@ -1711,11 +1710,11 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
     public void testPutAllAsyncFiltered() throws Exception {
         Map<String, Integer> map1 = F.asMap("key1", 1, "key2", 2);
 
-        IgniteFuture<?> f1 = cache().putAllAsync(map1, F.<String, Integer>cacheNoPeekValue());
+        InternalFuture<?> f1 = cache().putAllAsync(map1, F.<String, Integer>cacheNoPeekValue());
 
         Map<String, Integer> map2 = F.asMap("key1", 10, "key2", 20, "key3", 3);
 
-        IgniteFuture<?> f2 = cache().putAllAsync(map2, F.<String, Integer>cacheNoPeekValue());
+        InternalFuture<?> f2 = cache().putAllAsync(map2, F.<String, Integer>cacheNoPeekValue());
 
         f2.get();
         f1.get();
@@ -1809,12 +1808,12 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
         GridCacheTx tx = txEnabled() ? cache().txStart() : null;
 
         try {
-            IgniteFuture<Integer> fut1 = cache().putIfAbsentAsync("key", 1);
+            InternalFuture<Integer> fut1 = cache().putIfAbsentAsync("key", 1);
 
             assert fut1.get() == null;
             assert cache().get("key") != null && cache().get("key") == 1;
 
-            IgniteFuture<Integer> fut2 = cache().putIfAbsentAsync("key", 2);
+            InternalFuture<Integer> fut2 = cache().putIfAbsentAsync("key", 2);
 
             assert fut2.get() != null && fut2.get() == 1;
             assert cache().get("key") != null && cache().get("key") == 1;
@@ -1925,12 +1924,12 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
      * @throws Exception If failed.
      */
     private void checkPutxIfAbsentAsync(boolean inTx) throws Exception {
-        IgniteFuture<Boolean> fut1 = cache().putxIfAbsentAsync("key", 1);
+        InternalFuture<Boolean> fut1 = cache().putxIfAbsentAsync("key", 1);
 
         assert fut1.get();
         assert cache().get("key") != null && cache().get("key") == 1;
 
-        IgniteFuture<Boolean> fut2 = cache().putxIfAbsentAsync("key", 2);
+        InternalFuture<Boolean> fut2 = cache().putxIfAbsentAsync("key", 2);
 
         assert !fut2.get();
         assert cache().get("key") != null && cache().get("key") == 1;
@@ -1973,8 +1972,8 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
      * @throws Exception In case of error.
      */
     public void testPutxIfAbsentAsyncConcurrent() throws Exception {
-        IgniteFuture<Boolean> fut1 = cache().putxIfAbsentAsync("key1", 1);
-        IgniteFuture<Boolean> fut2 = cache().putxIfAbsentAsync("key2", 2);
+        InternalFuture<Boolean> fut1 = cache().putxIfAbsentAsync("key1", 1);
+        InternalFuture<Boolean> fut2 = cache().putxIfAbsentAsync("key2", 2);
 
         assert fut1.get();
         assert fut2.get();
@@ -3302,13 +3301,13 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
             comp.call(new Callable<Boolean>() {
                 @Override
                 public Boolean call() throws Exception {
-                    IgniteFuture<Boolean> f = cache().lockAsync("key", 1000);
+                    InternalFuture<Boolean> f = cache().lockAsync("key", 1000);
 
                     try {
                         f.get(100);
 
                         fail();
-                    } catch (IgniteFutureTimeoutException ex) {
+                    } catch (InternalFutureTimeoutException ex) {
                         info("Caught expected exception: " + ex);
                     }
 
@@ -3324,7 +3323,7 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
                 }
             });
 
-            IgniteFuture<Boolean> f = comp.future();
+            InternalFuture<Boolean> f = comp.future();
 
                 // Let another thread start.
             latch.await();
@@ -3381,13 +3380,13 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
                 @Override public Boolean call() throws Exception {
                     syncLatch.countDown();
 
-                    IgniteFuture<Boolean> f = e.lockAsync(1000);
+                    InternalFuture<Boolean> f = e.lockAsync(1000);
 
                     try {
                         f.get(100);
 
                         fail();
-                    } catch (IgniteFutureTimeoutException ex) {
+                    } catch (InternalFutureTimeoutException ex) {
                         info("Caught expected exception: " + ex);
                     }
 
@@ -3401,7 +3400,7 @@ public abstract class GridCacheAbstractFullApiSelfTest extends GridCacheAbstract
                 }
             });
 
-            IgniteFuture<Boolean> f = comp.future();
+            InternalFuture<Boolean> f = comp.future();
 
             syncLatch.await();
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
index 6aae0f6..083ce73 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
@@ -138,7 +138,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
                 try {
                     U.sleep(500);
                 }
-                catch (GridInterruptedException ignore) {
+                catch (InternalInterruptedException ignore) {
                     // No-op.
                 }
 
@@ -247,8 +247,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testApply1() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
                 IgniteCompute comp = compute(grid).enableAsync();
 
                 comp.apply(new TestClosure(), "arg");
@@ -262,8 +262,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testApply2() throws Exception {
-        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
                 IgniteCompute comp = compute(grid).enableAsync();
 
                 comp.apply(new TestClosure(), Arrays.asList("arg1", "arg2"));
@@ -277,8 +277,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testApply3() throws Exception {
-        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
                 IgniteCompute comp = compute(grid).enableAsync();
 
                 comp.apply(new TestClosure(),
@@ -302,8 +302,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testRun1() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.run(new TestRunnable());
@@ -317,8 +317,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testRun2() throws Exception {
-        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.run(Arrays.asList(new TestRunnable(), new TestRunnable()));
@@ -332,8 +332,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testCall1() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.call(new TestCallable());
@@ -347,8 +347,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testCall2() throws Exception {
-        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.call(Arrays.asList(new TestCallable(), new TestCallable()));
@@ -362,8 +362,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testCall3() throws Exception {
-        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.call(
@@ -387,8 +387,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testBroadcast1() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.broadcast(new TestRunnable());
@@ -402,8 +402,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testBroadcast2() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.broadcast(new TestCallable());
@@ -417,8 +417,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testBroadcast3() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.broadcast(new TestClosure(), "arg");
@@ -432,8 +432,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testAffinityRun() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 GridCacheAffinity<Object> aff = prj.ignite().cache(null).affinity();
@@ -451,8 +451,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testAffinityCall() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, InternalFuture<?>>() {
+            @Override public InternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 GridCacheAffinity<Object> aff = prj.ignite().cache(null).affinity();
@@ -494,7 +494,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @param taskStarter Task started.
      * @throws Exception If failed.
      */
-    private void testMasterLeaveAwareCallback(int expJobs, IgniteClosure<ClusterGroup, IgniteFuture<?>> taskStarter)
+    private void testMasterLeaveAwareCallback(int expJobs, IgniteClosure<ClusterGroup, InternalFuture<?>> taskStarter)
         throws Exception {
         jobLatch = new CountDownLatch(expJobs);
         invokeLatch  = new CountDownLatch(expJobs);
@@ -504,7 +504,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
 
         int lastGridIdx = GRID_CNT - 1;
 
-        IgniteFuture<?> fut = taskStarter.apply(grid(lastGridIdx).forPredicate(excludeLastPredicate()));
+        InternalFuture<?> fut = taskStarter.apply(grid(lastGridIdx).forPredicate(excludeLastPredicate()));
 
         jobLatch.await();
 
@@ -755,7 +755,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
                         try {
                             U.await(waitLatch);
                         }
-                        catch (GridInterruptedException ignore) {
+                        catch (InternalInterruptedException ignore) {
                             // No-op.
                         }
                     }
@@ -790,9 +790,9 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
         /**
          * Await for job execution response to come.
          *
          * @throws GridInterruptedException If interrupted.
          */
-        private void awaitResponse() throws GridInterruptedException{
+        private void awaitResponse() throws InternalInterruptedException {
             U.await(respLatch);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobStealingSelfTest.java
----------------------------------------------------------------------
@@ -790,9 +790,9 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
          * Await for job execution response to come.
          *
-         * @throws GridInterruptedException If interrupted.
+         * @throws InternalInterruptedException If interrupted.
          */
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/managers/checkpoint/GridCheckpointManagerAbstractSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/managers/checkpoint/GridCheckpointManagerAbstractSelfTest.java
index ace207c..d8558e3 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/managers/checkpoint/GridCheckpointManagerAbstractSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/managers/checkpoint/GridCheckpointManagerAbstractSelfTest.java
@@ -243,7 +243,7 @@ public abstract class GridCheckpointManagerAbstractSelfTest extends GridCommonAb
 
             Ignite ignite = startGrid(gridName);
 
-            IgniteFuture fut = executeAsync(ignite.compute(), new GridMultiNodeGlobalConsumerTask(), null);
+            InternalFuture fut = executeAsync(ignite.compute(), new GridMultiNodeGlobalConsumerTask(), null);
 
             executeAsync(ignite.compute(), GridMultiNodeTestCheckPointTask.class, null).get(2 * 60 * 1000);
 
@@ -740,9 +740,9 @@ public abstract class GridCheckpointManagerAbstractSelfTest extends GridCommonAb
      * Wrapper around {@link GridTestUtils#retryAssert(org.apache.ignite.IgniteLogger, int, long, GridAbsClosure)}.
      * For the given closure provides count of retries, configured by {@link #retries} attribute.
      * @param assertion Closure with assertion inside.
      * @throws GridInterruptedException If was interrupted.
      */
-    private static void assertWithRetries(GridAbsClosureX assertion) throws GridInterruptedException {
+    private static void assertWithRetries(GridAbsClosureX assertion) throws InternalInterruptedException {
         GridTestUtils.retryAssert(null, retries, 5000, assertion);
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/managers/deployment/GridDeploymentMessageCountSelfTest.java
----------------------------------------------------------------------
@@ -740,9 +740,9 @@ public abstract class GridCheckpointManagerAbstractSelfTest extends GridCommonAb
      * For the given closure provides count of retries, configured by {@link #retries} attribute.
      * @param assertion Closure with assertion inside.
-     * @throws GridInterruptedException If was interrupted.
+     * @throws InternalInterruptedException If was interrupted.
      */